=======
msprime
=======

Msprime is a coalescent simulator and library for processing
tree-based genetic data. Msprime can simulate the coalescent with
recombination over whole chromosomes for hundreds of thousands of
samples, and very efficiently process the resulting genealogies.
It is also possible to efficiently read data from external
sources via a well defined and efficient `interchange API
<https://msprime.readthedocs.org/en/stable/interchange.html>`_.

If you use ``msprime`` in your work, please cite the `PLOS Computational
Biology <http://dx.doi.org/10.1371/journal.pcbi.1004842>`_ paper.
See `here <https://msprime.readthedocs.org/en/stable/CITATION.html>`__ for
full citation details.

Please see the `documentation <https://msprime.readthedocs.org/en/stable/>`_
for further details.

Msprime is very portable, and provides a number of installation options.
See `here <https://msprime.readthedocs.org/en/stable/installation.html>`_ for
details.
